EcmpPayment class

Annotations
  • @JsonSerializable.new()

Constructors

EcmpPayment(String id, String status, String method, int sum, String? type, String? token, String? currency, String? paymentMassage)
EcmpPayment.fromJson(Map<String, dynamic> data)
factory

Properties

currency → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
method → String
final
paymentMassage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
sum → int
final
token → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited